package com.myoa.engineering.crawl.shopping.service.slack;

import com.myoa.engineering.crawl.shopping.configuration.slack.properties.SlackSecretProperties;
import com.slack.api.methods.MethodsClient;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

@Slf4j
@Service
public class UserNotifyService {

    private static final String SLACK_PROPERTIES_UNIT_NAME = "shopping-crawler";

    private final SlackSecretProperties.SlackSecretPropertiesUnit slackSecretProperties;
    private final MethodsClient methodsClient;

    public UserNotifyService(SlackSecretProperties slackSecretProperties,
                             MethodsClient methodsClient) {
        this.slackSecretProperties = slackSecretProperties.find(SLACK_PROPERTIES_UNIT_NAME);
        this.methodsClient = methodsClient;
    }

    public void notify(String message) {
        try {
            methodsClient.chatPostMessage(req -> req
                    .channel(slackSecretProperties.getChannel())
                    .username(slackSecretProperties.getUsername())
                    .text(message));
        } catch (Exception e) {
            log.warn("Failed. message: {}", message, e);
        }
    }
}
